==> kubernetes-model-kustomize-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/LabelFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LabelFluent<A extends LabelFluent<A>> extends Fluent<A>{
  public A addToFields(Integer index,FieldSpec item);
  public A setToFields(Integer index,FieldSpec item);
  public A addToFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... items);
  public A addAllToFields(Collection<FieldSpec> items);
  public A removeFromFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... items);
  public A removeAllFromFields(Collection<FieldSpec> items);
  public A removeMatchingFromFields(Predicate<FieldSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFields instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FieldSpec> getFields();
  public List<FieldSpec> buildFields();
  public FieldSpec buildField(Integer index);
  public FieldSpec buildFirstField();
  public FieldSpec buildLastField();
  public FieldSpec buildMatchingField(Predicate<FieldSpecBuilder> predicate);
  public Boolean hasMatchingField(Predicate<FieldSpecBuilder> predicate);
  public A withFields(List<FieldSpec> fields);
  public A withFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... fields);
  public Boolean hasFields();
  public A addNewField(Boolean create,String group,String kind,String path,String version);
  public LabelFluent.FieldsNested<A> addNewField();
  public LabelFluent.FieldsNested<A> addNewFieldLike(FieldSpec item);
  public LabelFluent.FieldsNested<A> setNewFieldLike(Integer index,FieldSpec item);
  public LabelFluent.FieldsNested<A> editField(Integer index);
  public LabelFluent.FieldsNested<A> editFirstField();
  public LabelFluent.FieldsNested<A> editLastField();
  public LabelFluent.FieldsNested<A> editMatchingField(Predicate<FieldSpecBuilder> predicate);
  public Boolean getIncludeSelectors();
  public A withIncludeSelectors(Boolean includeSelectors);
  public Boolean hasIncludeSelectors();
  public Boolean getIncludeTemplates();
  public A withIncludeTemplates(Boolean includeTemplates);
  public Boolean hasIncludeTemplates();
  public A addToPairs(String key,String value);
  public A addToPairs(Map<String,String> map);
  public A removeFromPairs(String key);
  public A removeFromPairs(Map<String,String> map);
  public Map<String,String> getPairs();
  public <K,V>A withPairs(Map<String,String> pairs);
  public Boolean hasPairs();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withIncludeSelectors();
  public A withIncludeTemplates();
  public interface FieldsNested<N> extends Nested<N>,FieldSpecFluent<LabelFluent.FieldsNested<N>>{
    public N and();
    public N endField();
    
  }
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/LabelFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LabelFluent<A extends LabelFluent<A>> extends Fluent<A>{
  public A addToFields(int index,FieldSpec item);
  public A setToFields(int index,FieldSpec item);
  public A addToFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... items);
  public A addAllToFields(Collection<FieldSpec> items);
  public A removeFromFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... items);
  public A removeAllFromFields(Collection<FieldSpec> items);
  public A removeMatchingFromFields(Predicate<FieldSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFields instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FieldSpec> getFields();
  public List<FieldSpec> buildFields();
  public FieldSpec buildField(int index);
  public FieldSpec buildFirstField();
  public FieldSpec buildLastField();
  public FieldSpec buildMatchingField(Predicate<FieldSpecBuilder> predicate);
  public Boolean hasMatchingField(Predicate<FieldSpecBuilder> predicate);
  public A withFields(List<FieldSpec> fields);
  public A withFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... fields);
  public Boolean hasFields();
  public A addNewField(Boolean create,String group,String kind,String path,String version);
  public LabelFluent.FieldsNested<A> addNewField();
  public LabelFluent.FieldsNested<A> addNewFieldLike(FieldSpec item);
  public LabelFluent.FieldsNested<A> setNewFieldLike(int index,FieldSpec item);
  public LabelFluent.FieldsNested<A> editField(int index);
  public LabelFluent.FieldsNested<A> editFirstField();
  public LabelFluent.FieldsNested<A> editLastField();
  public LabelFluent.FieldsNested<A> editMatchingField(Predicate<FieldSpecBuilder> predicate);
  public Boolean getIncludeSelectors();
  public A withIncludeSelectors(Boolean includeSelectors);
  public Boolean hasIncludeSelectors();
  public Boolean getIncludeTemplates();
  public A withIncludeTemplates(Boolean includeTemplates);
  public Boolean hasIncludeTemplates();
  public A addToPairs(String key,String value);
  public A addToPairs(Map<String,String> map);
  public A removeFromPairs(String key);
  public A removeFromPairs(Map<String,String> map);
  public Map<String,String> getPairs();
  public <K,V>A withPairs(Map<String,String> pairs);
  public Boolean hasPairs();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withIncludeSelectors();
  public A withIncludeTemplates();
  public interface FieldsNested<N> extends Nested<N>,FieldSpecFluent<LabelFluent.FieldsNested<N>>{
    public N and();
    public N endField();
    
  }
  
}
